@@ -14,7 +14,8 @@ class SessionTest(CliTestCase):
         self.assertEqual(result.exit_code, 0)
 
         payload = json.loads(responses.calls[0].request.body.decode())
-        self.assert_json_orderless_equal({"flavors": {}}, payload)
+        self.assert_json_orderless_equal(
+            {"flavors": {}, "observation": False}, payload)
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -24,11 +25,13 @@ class SessionTest(CliTestCase):
         self.assertEqual(result.exit_code, 0)
 
         payload = json.loads(responses.calls[0].request.body.decode())
-        self.assert_json_orderless_equal({"flavors": {
-            "key": "value",
-            "k": "v",
-            "k e y": "v a l u e",
-        }}, payload)
+        self.assert_json_orderless_equal({
+            "flavors": {
+                "key": "value",
+                "k": "v",
+                "k e y": "v a l u e",
+            },
+            "observation": False, }, payload)
 
         with self.assertRaises(ValueError):
             result = self.cli("record", "session", "--build", self.build_name,
@@ -36,3 +39,14 @@ class SessionTest(CliTestCase):
             self.assertEqual(result.exit_code, 1)
             self.assertTrue(
                 "Expected key-value like --option kye=value or --option key value." in result.output)
+
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
+    def test_run_session_with_observation(self):
+        result = self.cli("record", "session", "--build",
+                          self.build_name, "--observation")
+        self.assertEqual(result.exit_code, 0)
+
+        payload = json.loads(responses.calls[0].request.body.decode())
+        self.assert_json_orderless_equal(
+            {"flavors": {}, "observation": True}, payload)
